package javax.swing.plaf.synth;

import java.awt.event.MouseEvent;
import java.beans.PropertyChangeEvent;
import sun.swing.SwingUtilities2;
import java.awt.Graphics;
import java.awt.Point;
import java.util.Enumeration;
import java.util.Dictionary;
import java.awt.FontMetrics;
import java.awt.Insets;
import javax.swing.JSlider;
import javax.swing.plaf.ComponentUI;
import javax.swing.JComponent;
import java.awt.Dimension;
import java.awt.Rectangle;
import java.beans.PropertyChangeListener;
import javax.swing.plaf.basic.BasicSliderUI;

public class SynthSliderUI extends BasicSliderUI implements PropertyChangeListener, SynthUI
{
    private Rectangle valueRect;
    private boolean paintValue;
    private Dimension lastSize;
    private int trackHeight;
    private int trackBorder;
    private int thumbWidth;
    private int thumbHeight;
    private SynthStyle style;
    private SynthStyle sliderTrackStyle;
    private SynthStyle sliderThumbStyle;
    private transient boolean thumbActive;
    private transient boolean thumbPressed;
    
    public static ComponentUI createUI(JComponent component) {
        return new SynthSliderUI((JSlider)component);
    }
    
    protected SynthSliderUI(JSlider b) {
        super(b);
        this.valueRect = new Rectangle();
    }
    
    @Override
    protected void installDefaults(JSlider slider) {
        this.updateStyle(slider);
    }
    
    @Override
    protected void uninstallDefaults(JSlider slider) {
        SynthContext context = this.getContext(slider, 1);
        this.style.uninstallDefaults(context);
        context.dispose();
        this.style = null;
        SynthContext context2 = this.getContext(slider, Region.SLIDER_TRACK, 1);
        this.sliderTrackStyle.uninstallDefaults(context2);
        context2.dispose();
        this.sliderTrackStyle = null;
        SynthContext context3 = this.getContext(slider, Region.SLIDER_THUMB, 1);
        this.sliderThumbStyle.uninstallDefaults(context3);
        context3.dispose();
        this.sliderThumbStyle = null;
    }
    
    @Override
    protected void installListeners(JSlider slider) {
        super.installListeners(slider);
        slider.addPropertyChangeListener(this);
    }
    
    @Override
    protected void uninstallListeners(JSlider slider) {
        slider.removePropertyChangeListener(this);
        super.uninstallListeners(slider);
    }
    
    private void updateStyle(JSlider slider) {
        SynthContext context = this.getContext(slider, 1);
        SynthStyle style = this.style;
        this.style = SynthLookAndFeel.updateStyle(context, this);
        if (this.style != style) {
            this.thumbWidth = this.style.getInt(context, "Slider.thumbWidth", 30);
            this.thumbHeight = this.style.getInt(context, "Slider.thumbHeight", 14);
            String anObject = (String)this.slider.getClientProperty("JComponent.sizeVariant");
            if (anObject != null) {
                if ("large".equals(anObject)) {
                    this.thumbWidth = (int)((double)this.thumbWidth * 1.15);
                    this.thumbHeight = (int)((double)this.thumbHeight * 1.15);
                }
                else if ("small".equals(anObject)) {
                    this.thumbWidth = (int)((double)this.thumbWidth * 0.857);
                    this.thumbHeight = (int)((double)this.thumbHeight * 0.857);
                }
                else if ("mini".equals(anObject)) {
                    this.thumbWidth = (int)((double)this.thumbWidth * 0.784);
                    this.thumbHeight = (int)((double)this.thumbHeight * 0.784);
                }
            }
            this.trackBorder = this.style.getInt(context, "Slider.trackBorder", 1);
            this.trackHeight = this.thumbHeight + this.trackBorder * 2;
            this.paintValue = this.style.getBoolean(context, "Slider.paintValue", true);
            if (style != null) {
                this.uninstallKeyboardActions(slider);
                this.installKeyboardActions(slider);
            }
        }
        context.dispose();
        SynthContext context2 = this.getContext(slider, Region.SLIDER_TRACK, 1);
        this.sliderTrackStyle = SynthLookAndFeel.updateStyle(context2, this);
        context2.dispose();
        SynthContext context3 = this.getContext(slider, Region.SLIDER_THUMB, 1);
        this.sliderThumbStyle = SynthLookAndFeel.updateStyle(context3, this);
        context3.dispose();
    }
    
    @Override
    protected BasicSliderUI.TrackListener createTrackListener(JSlider slider) {
        return new SynthSliderUI.SynthTrackListener();
    }
    
    private void updateThumbState(int x, int y) {
        this.setThumbActive(this.thumbRect.contains(x, y));
    }
    
    private void updateThumbState(int n, int n2, boolean thumbPressed) {
        this.updateThumbState(n, n2);
        this.setThumbPressed(thumbPressed);
    }
    
    private void setThumbActive(boolean thumbActive) {
        if (this.thumbActive != thumbActive) {
            this.thumbActive = thumbActive;
            this.slider.repaint(this.thumbRect);
        }
    }
    
    private void setThumbPressed(boolean thumbPressed) {
        if (this.thumbPressed != thumbPressed) {
            this.thumbPressed = thumbPressed;
            this.slider.repaint(this.thumbRect);
        }
    }
    
    @Override
    public int getBaseline(JComponent component, int n, int n2) {
        if (component == null) {
            throw new NullPointerException("Component must be non-null");
        }
        if (n < 0 || n2 < 0) {
            throw new IllegalArgumentException("Width and height must be >= 0");
        }
        if (this.slider.getPaintLabels() && this.labelsHaveSameBaselines()) {
            Insets insets = new Insets(0, 0, 0, 0);
            SynthContext context = this.getContext(this.slider, Region.SLIDER_TRACK);
            this.style.getInsets(context, insets);
            context.dispose();
            if (this.slider.getOrientation() == 0) {
                int maximumCharHeight2 = 0;
                if (this.paintValue) {
                    SynthContext context3 = this.getContext(this.slider);
                    maximumCharHeight2 = context3.getStyle().getGraphicsUtils(context3).getMaximumCharHeight(context3);
                    context3.dispose();
                }
                int tickLength = 0;
                if (this.slider.getPaintTicks()) {
                    tickLength = this.getTickLength();
                }
                int n4 = n2 / 2 - (maximumCharHeight2 + this.trackHeight + insets.top + insets.bottom + tickLength + this.getHeightOfTallestLabel() + 4) / 2 + (maximumCharHeight2 + 2) + (this.trackHeight + insets.top + insets.bottom) + (tickLength + 2);
                JComponent component3 = (JComponent)this.slider.getLabelTable().elements().nextElement();
                Dimension preferredSize2 = component3.getPreferredSize();
                return n4 + component3.getBaseline(preferredSize2.width, preferredSize2.height);
            }
            else {
                Integer n3 = this.slider.getInverted() ? this.getLowestValue() : this.getHighestValue();
                if (n3 != null) {
                    int top = this.insetCache.top;
                    int maximumCharHeight = 0;
                    if (this.paintValue) {
                        SynthContext context2 = this.getContext(this.slider);
                        maximumCharHeight = context2.getStyle().getGraphicsUtils(context2).getMaximumCharHeight(context2);
                        context2.dispose();
                    }
                    int yPositionForValue = this.yPositionForValue((int)n3, top + maximumCharHeight, n2 - this.insetCache.top - this.insetCache.bottom - maximumCharHeight);
                    JComponent component2 = (JComponent)this.slider.getLabelTable().get(n3);
                    Dimension preferredSize = component2.getPreferredSize();
                    return yPositionForValue - preferredSize.height / 2 + component2.getBaseline(preferredSize.width, preferredSize.height);
                }
            }
        }
        return -1;
    }
    
    @Override
    public Dimension getPreferredSize(JComponent component) {
        this.recalculateIfInsetsChanged();
        Dimension dimension = new Dimension(this.contentRect.width, this.contentRect.height);
        if (this.slider.getOrientation() == 1) {
            dimension.height = 200;
        }
        else {
            dimension.width = 200;
        }
        Insets insets = this.slider.getInsets();
        dimension.width += insets.left + insets.right;
        dimension.height += insets.top + insets.bottom;
        return dimension;
    }
    
    @Override
    public Dimension getMinimumSize(JComponent component) {
        this.recalculateIfInsetsChanged();
        Dimension dimension = new Dimension(this.contentRect.width, this.contentRect.height);
        if (this.slider.getOrientation() == 1) {
            dimension.height = this.thumbRect.height + this.insetCache.top + this.insetCache.bottom;
            return dimension;
        }
        dimension.width = this.thumbRect.width + this.insetCache.left + this.insetCache.right;
        return dimension;
    }
    
    @Override
    protected void calculateGeometry() {
        this.calculateThumbSize();
        this.layout();
        this.calculateThumbLocation();
    }
    
    protected void layout() {
        SynthContext context = this.getContext(this.slider);
        SynthGraphicsUtils graphicsUtils = this.style.getGraphicsUtils(context);
        Insets insets = new Insets(0, 0, 0, 0);
        SynthContext context2 = this.getContext(this.slider, Region.SLIDER_TRACK);
        this.style.getInsets(context2, insets);
        context2.dispose();
        if (this.slider.getOrientation() == 0) {
            this.valueRect.height = 0;
            if (this.paintValue) {
                this.valueRect.height = graphicsUtils.getMaximumCharHeight(context);
            }
            this.trackRect.height = this.trackHeight;
            this.tickRect.height = 0;
            if (this.slider.getPaintTicks()) {
                this.tickRect.height = this.getTickLength();
            }
            this.labelRect.height = 0;
            if (this.slider.getPaintLabels()) {
                this.labelRect.height = this.getHeightOfTallestLabel();
            }
            this.contentRect.height = this.valueRect.height + this.trackRect.height + insets.top + insets.bottom + this.tickRect.height + this.labelRect.height + 4;
            this.contentRect.width = this.slider.getWidth() - this.insetCache.left - this.insetCache.right;
            int max = 0;
            if (this.slider.getPaintLabels()) {
                this.trackRect.x = this.insetCache.left;
                this.trackRect.width = this.contentRect.width;
                Dictionary<Object, Object> labelTable = this.slider.getLabelTable();
                if (labelTable != null) {
                    int minimum = this.slider.getMinimum();
                    int maximum = this.slider.getMaximum();
                    int n2 = Integer.MAX_VALUE;
                    int n3 = Integer.MIN_VALUE;
                    Enumeration<Object> keys = labelTable.keys();
                    while (keys.hasMoreElements()) {
                        int intValue = (int)keys.nextElement();
                        if (intValue >= minimum && intValue < n2) {
                            n2 = intValue;
                        }
                        if (intValue <= maximum && intValue > n3) {
                            n3 = intValue;
                        }
                        else {
                            continue;
                        }
                    }
                    max = Math.max(this.getPadForLabel(n2), this.getPadForLabel(n3));
                }
            }
            Rectangle valueRect = this.valueRect;
            Rectangle trackRect3 = this.trackRect;
            Rectangle tickRect3 = this.tickRect;
            Rectangle labelRect3 = this.labelRect;
            int n4 = this.insetCache.left + max;
            labelRect3.x = n4;
            tickRect3.x = n4;
            trackRect3.x = n4;
            valueRect.x = n4;
            Rectangle valueRect2 = this.valueRect;
            Rectangle trackRect4 = this.trackRect;
            Rectangle tickRect4 = this.tickRect;
            Rectangle labelRect4 = this.labelRect;
            int n5 = this.contentRect.width - max * 2;
            labelRect4.width = n5;
            tickRect4.width = n5;
            trackRect4.width = n5;
            valueRect2.width = n5;
            int y2 = this.slider.getHeight() / 2 - this.contentRect.height / 2;
            this.valueRect.y = y2;
            int n6 = y2 + (this.valueRect.height + 2);
            this.trackRect.y = n6 + insets.top;
            int y3 = n6 + (this.trackRect.height + insets.top + insets.bottom);
            this.tickRect.y = y3;
            int y4 = y3 + (this.tickRect.height + 2);
            this.labelRect.y = y4;
            int n7 = y4 + this.labelRect.height;
        }
        else {
            this.trackRect.width = this.trackHeight;
            this.tickRect.width = 0;
            if (this.slider.getPaintTicks()) {
                this.tickRect.width = this.getTickLength();
            }
            this.labelRect.width = 0;
            if (this.slider.getPaintLabels()) {
                this.labelRect.width = this.getWidthOfWidestLabel();
            }
            this.valueRect.y = this.insetCache.top;
            this.valueRect.height = 0;
            if (this.paintValue) {
                this.valueRect.height = graphicsUtils.getMaximumCharHeight(context);
            }
            FontMetrics fontMetrics = this.slider.getFontMetrics(this.slider.getFont());
            this.valueRect.width = Math.max(graphicsUtils.computeStringWidth(context, this.slider.getFont(), fontMetrics, "" + this.slider.getMaximum()), graphicsUtils.computeStringWidth(context, this.slider.getFont(), fontMetrics, "" + this.slider.getMinimum()));
            int n = this.valueRect.width / 2;
            int a = insets.left + this.trackRect.width / 2;
            int a2 = this.trackRect.width / 2 + insets.right + this.tickRect.width + this.labelRect.width;
            this.contentRect.width = Math.max(a, n) + Math.max(a2, n) + 2 + this.insetCache.left + this.insetCache.right;
            this.contentRect.height = this.slider.getHeight() - this.insetCache.top - this.insetCache.bottom;
            Rectangle trackRect = this.trackRect;
            Rectangle tickRect = this.tickRect;
            Rectangle labelRect = this.labelRect;
            int y = this.valueRect.y + this.valueRect.height;
            labelRect.y = y;
            tickRect.y = y;
            trackRect.y = y;
            Rectangle trackRect2 = this.trackRect;
            Rectangle tickRect2 = this.tickRect;
            Rectangle labelRect2 = this.labelRect;
            int height = this.contentRect.height - this.valueRect.height;
            labelRect2.height = height;
            tickRect2.height = height;
            trackRect2.height = height;
            int x = this.slider.getWidth() / 2 - this.contentRect.width / 2;
            if (SynthLookAndFeel.isLeftToRight(this.slider)) {
                if (n > a) {
                    x += n - a;
                }
                this.trackRect.x = x + insets.left;
                int x3 = x + (insets.left + this.trackRect.width + insets.right);
                this.tickRect.x = x3;
                this.labelRect.x = x3 + this.tickRect.width + 2;
            }
            else {
                if (n > a2) {
                    x += n - a2;
                }
                this.labelRect.x = x;
                int x2 = x + (this.labelRect.width + 2);
                this.tickRect.x = x2;
                this.trackRect.x = x2 + this.tickRect.width + insets.left;
            }
        }
        context.dispose();
        this.lastSize = this.slider.getSize();
    }
    
    private int getPadForLabel(int i) {
        int n = 0;
        JComponent component = (JComponent)this.slider.getLabelTable().get(Integer.valueOf(i));
        if (component != null) {
            int xPositionForValue = this.xPositionForValue(i);
            int n2 = component.getPreferredSize().width / 2;
            if (xPositionForValue - n2 < this.insetCache.left) {
                n = Math.max(n, this.insetCache.left - (xPositionForValue - n2));
            }
            if (xPositionForValue + n2 > this.slider.getWidth() - this.insetCache.right) {
                n = Math.max(n, xPositionForValue + n2 - (this.slider.getWidth() - this.insetCache.right));
            }
        }
        return n;
    }
    
    @Override
    protected void calculateThumbLocation() {
        super.calculateThumbLocation();
        if (this.slider.getOrientation() == 0) {
            Rectangle thumbRect2 = this.thumbRect;
            thumbRect2.y += this.trackBorder;
        }
        else {
            Rectangle thumbRect = this.thumbRect;
            thumbRect.x += this.trackBorder;
        }
        Point mousePosition = this.slider.getMousePosition();
        if (mousePosition != null) {
            this.updateThumbState(mousePosition.x, mousePosition.y);
        }
    }
    
    @Override
    public void setThumbLocation(int x, int y) {
        super.setThumbLocation(x, y);
        this.slider.repaint(this.valueRect.x, this.valueRect.y, this.valueRect.width, this.valueRect.height);
        this.setThumbActive(false);
    }
    
    @Override
    protected int xPositionForValue(int n) {
        int minimum = this.slider.getMinimum();
        int maximum = this.slider.getMaximum();
        int a = this.trackRect.x + this.thumbRect.width / 2 + this.trackBorder;
        int a2 = this.trackRect.x + this.trackRect.width - this.thumbRect.width / 2 - this.trackBorder;
        double n2 = (double)(a2 - a) / ((double)maximum - (double)minimum);
        int b;
        if (!this.drawInverted()) {
            b = (int)((long)a + Math.round(n2 * ((double)n - (double)minimum)));
        }
        else {
            b = (int)((long)a2 - Math.round(n2 * ((double)n - (double)minimum)));
        }
        return Math.min(a2, Math.max(a, b));
    }
    
    @Override
    protected int yPositionForValue(int n, int n2, int n3) {
        int minimum = this.slider.getMinimum();
        int maximum = this.slider.getMaximum();
        int a = n2 + this.thumbRect.height / 2 + this.trackBorder;
        int a2 = n2 + n3 - this.thumbRect.height / 2 - this.trackBorder;
        double n4 = (double)(a2 - a) / ((double)maximum - (double)minimum);
        int b;
        if (!this.drawInverted()) {
            b = (int)((long)a + Math.round(n4 * ((double)maximum - (double)n)));
        }
        else {
            b = (int)((long)a + Math.round(n4 * ((double)n - (double)minimum)));
        }
        return Math.min(a2, Math.max(a, b));
    }
    
    @Override
    public int valueForYPosition(int n) {
        int minimum = this.slider.getMinimum();
        int maximum = this.slider.getMaximum();
        int n2 = this.trackRect.y + this.thumbRect.height / 2 + this.trackBorder;
        int n3 = this.trackRect.y + this.trackRect.height - this.thumbRect.height / 2 - this.trackBorder;
        int n4 = n3 - n2;
        if (n <= n2) {
            maximum = (this.drawInverted() ? minimum : maximum);
        }
        else if (n >= n3) {
            maximum = (this.drawInverted() ? maximum : minimum);
        }
        else {
            int n5 = (int)Math.round((double)(n - n2) * (((double)maximum - (double)minimum) / (double)n4));
            maximum = (this.drawInverted() ? (minimum + n5) : (maximum - n5));
        }
        return maximum;
    }
    
    @Override
    public int valueForXPosition(int n) {
        int minimum = this.slider.getMinimum();
        int maximum = this.slider.getMaximum();
        int n2 = this.trackRect.x + this.thumbRect.width / 2 + this.trackBorder;
        int n3 = this.trackRect.x + this.trackRect.width - this.thumbRect.width / 2 - this.trackBorder;
        int n4 = n3 - n2;
        if (n <= n2) {
            minimum = (this.drawInverted() ? maximum : minimum);
        }
        else if (n >= n3) {
            minimum = (this.drawInverted() ? minimum : maximum);
        }
        else {
            int n5 = (int)Math.round((double)(n - n2) * (((double)maximum - (double)minimum) / (double)n4));
            minimum = (this.drawInverted() ? (maximum - n5) : (minimum + n5));
        }
        return minimum;
    }
    
    @Override
    protected Dimension getThumbSize() {
        Dimension dimension = new Dimension();
        if (this.slider.getOrientation() == 1) {
            dimension.width = this.thumbHeight;
            dimension.height = this.thumbWidth;
            return dimension;
        }
        dimension.width = this.thumbWidth;
        dimension.height = this.thumbHeight;
        return dimension;
    }
    
    @Override
    protected void recalculateIfInsetsChanged() {
        SynthContext context = this.getContext(this.slider);
        Insets insets = this.style.getInsets(context, null);
        Insets insets2 = this.slider.getInsets();
        insets.left += insets2.left;
        insets.right += insets2.right;
        insets.top += insets2.top;
        insets.bottom += insets2.bottom;
        if (!insets.equals(this.insetCache)) {
            this.insetCache = insets;
            this.calculateGeometry();
        }
        context.dispose();
    }
    
    @Override
    public SynthContext getContext(JComponent component) {
        return this.getContext(component, SynthLookAndFeel.getComponentState(component));
    }
    
    private SynthContext getContext(JComponent component, int n) {
        return SynthContext.getContext(component, this.style, n);
    }
    
    private SynthContext getContext(JComponent component, Region region) {
        return this.getContext(component, region, this.getComponentState(component, region));
    }
    
    private SynthContext getContext(JComponent component, Region region, int n) {
        SynthStyle synthStyle = null;
        if (region == Region.SLIDER_TRACK) {
            synthStyle = this.sliderTrackStyle;
        }
        else if (region == Region.SLIDER_THUMB) {
            synthStyle = this.sliderThumbStyle;
        }
        return SynthContext.getContext(component, region, synthStyle, n);
    }
    
    private int getComponentState(JComponent component, Region region) {
        if (region == Region.SLIDER_THUMB && this.thumbActive && component.isEnabled()) {
            int n = this.thumbPressed ? 4 : 2;
            if (component.isFocusOwner()) {
                n |= 0x100;
            }
            return n;
        }
        else {
            return SynthLookAndFeel.getComponentState(component);
        }
    }
    
    @Override
    public void update(Graphics graphics, JComponent component) {
        SynthContext context = this.getContext(component);
        SynthLookAndFeel.update(context, graphics);
        context.getPainter().paintSliderBackground(context, graphics, 0, 0, component.getWidth(), component.getHeight(), this.slider.getOrientation());
        this.paint(context, graphics);
        context.dispose();
    }
    
    @Override
    public void paint(Graphics graphics, JComponent component) {
        SynthContext context = this.getContext(component);
        this.paint(context, graphics);
        context.dispose();
    }
    
    protected void paint(SynthContext synthContext, Graphics g) {
        this.recalculateIfInsetsChanged();
        this.recalculateIfOrientationChanged();
        Rectangle clipBounds = g.getClipBounds();
        if (this.lastSize == null || !this.lastSize.equals(this.slider.getSize())) {
            this.calculateGeometry();
        }
        if (this.paintValue) {
            int computeStringWidth = synthContext.getStyle().getGraphicsUtils(synthContext).computeStringWidth(synthContext, g.getFont(), SwingUtilities2.getFontMetrics(this.slider, g), "" + this.slider.getValue());
            this.valueRect.x = this.thumbRect.x + (this.thumbRect.width - computeStringWidth) / 2;
            if (this.slider.getOrientation() == 0) {
                if (this.valueRect.x + computeStringWidth > this.insetCache.left + this.contentRect.width) {
                    this.valueRect.x = this.insetCache.left + this.contentRect.width - computeStringWidth;
                }
                this.valueRect.x = Math.max(this.valueRect.x, 0);
            }
            g.setColor(synthContext.getStyle().getColor(synthContext, ColorType.TEXT_FOREGROUND));
            synthContext.getStyle().getGraphicsUtils(synthContext).paintText(synthContext, g, "" + this.slider.getValue(), this.valueRect.x, this.valueRect.y, -1);
        }
        if (this.slider.getPaintTrack() && clipBounds.intersects(this.trackRect)) {
            SynthContext context = this.getContext(this.slider, Region.SLIDER_TRACK);
            this.paintTrack(context, g, this.trackRect);
            context.dispose();
        }
        if (clipBounds.intersects(this.thumbRect)) {
            SynthContext context2 = this.getContext(this.slider, Region.SLIDER_THUMB);
            this.paintThumb(context2, g, this.thumbRect);
            context2.dispose();
        }
        if (this.slider.getPaintTicks() && clipBounds.intersects(this.tickRect)) {
            this.paintTicks(g);
        }
        if (this.slider.getPaintLabels() && clipBounds.intersects(this.labelRect)) {
            this.paintLabels(g);
        }
    }
    
    @Override
    public void paintBorder(SynthContext synthContext, Graphics graphics, int n, int n2, int n3, int n4) {
        synthContext.getPainter().paintSliderBorder(synthContext, graphics, n, n2, n3, n4, this.slider.getOrientation());
    }
    
    protected void paintThumb(SynthContext synthContext, Graphics graphics, Rectangle rectangle) {
        int orientation = this.slider.getOrientation();
        SynthLookAndFeel.updateSubregion(synthContext, graphics, rectangle);
        synthContext.getPainter().paintSliderThumbBackground(synthContext, graphics, rectangle.x, rectangle.y, rectangle.width, rectangle.height, orientation);
        synthContext.getPainter().paintSliderThumbBorder(synthContext, graphics, rectangle.x, rectangle.y, rectangle.width, rectangle.height, orientation);
    }
    
    protected void paintTrack(SynthContext synthContext, Graphics graphics, Rectangle rectangle) {
        int orientation = this.slider.getOrientation();
        SynthLookAndFeel.updateSubregion(synthContext, graphics, rectangle);
        synthContext.getPainter().paintSliderTrackBackground(synthContext, graphics, rectangle.x, rectangle.y, rectangle.width, rectangle.height, orientation);
        synthContext.getPainter().paintSliderTrackBorder(synthContext, graphics, rectangle.x, rectangle.y, rectangle.width, rectangle.height, orientation);
    }
    
    @Override
    public void propertyChange(PropertyChangeEvent propertyChangeEvent) {
        if (SynthLookAndFeel.shouldUpdateStyle(propertyChangeEvent)) {
            this.updateStyle((JSlider)propertyChangeEvent.getSource());
        }
    }
    
    static void access$100(SynthSliderUI synthSliderUI, boolean thumbActive) {
        synthSliderUI.setThumbActive(thumbActive);
    }
    
    static void access$300(SynthSliderUI synthSliderUI, boolean thumbPressed) {
        synthSliderUI.setThumbPressed(thumbPressed);
    }
    
    static void access$400(SynthSliderUI synthSliderUI, int n, int n2, boolean b) {
        synthSliderUI.updateThumbState(n, n2, b);
    }
    
    static boolean access$600(SynthSliderUI synthSliderUI) {
        return synthSliderUI.isDragging();
    }
    
    static int access$1600(SynthSliderUI synthSliderUI, int value) {
        return synthSliderUI.yPositionForValue(value);
    }
    
    static boolean access$1700(SynthSliderUI synthSliderUI) {
        return synthSliderUI.drawInverted();
    }
    
    static boolean access$2600(SynthSliderUI synthSliderUI) {
        return synthSliderUI.drawInverted();
    }
    
    static void access$3000(SynthSliderUI synthSliderUI, int n, int n2) {
        synthSliderUI.updateThumbState(n, n2);
    }
    
    private class SynthTrackListener extends BasicSliderUI.TrackListener
    {
        @Override
        public void mouseExited(MouseEvent mouseEvent) {
            SynthSliderUI.access$100(SynthSliderUI.this, false);
        }
        
        @Override
        public void mousePressed(MouseEvent e) {
            super.mousePressed(e);
            SynthSliderUI.access$300(SynthSliderUI.this, SynthSliderUI.this.thumbRect.contains(e.getX(), e.getY()));
        }
        
        @Override
        public void mouseReleased(MouseEvent e) {
            super.mouseReleased(e);
            SynthSliderUI.access$400(SynthSliderUI.this, e.getX(), e.getY(), false);
        }
        
        @Override
        public void mouseDragged(MouseEvent mouseEvent) {
            if (!SynthSliderUI.this.slider.isEnabled()) {
                return;
            }
            this.currentMouseX = mouseEvent.getX();
            this.currentMouseY = mouseEvent.getY();
            if (!SynthSliderUI.access$600(SynthSliderUI.this)) {
                return;
            }
            SynthSliderUI.this.slider.setValueIsAdjusting(true);
            switch (SynthSliderUI.this.slider.getOrientation()) {
                case 1: {
                    int n = SynthSliderUI.this.thumbRect.height / 2;
                    int a = mouseEvent.getY() - this.offset;
                    int y = SynthSliderUI.this.trackRect.y;
                    int n2 = SynthSliderUI.this.trackRect.y + SynthSliderUI.this.trackRect.height - n - SynthSliderUI.this.trackBorder;
                    int access$1600 = SynthSliderUI.access$1600(SynthSliderUI.this, SynthSliderUI.this.slider.getMaximum() - SynthSliderUI.this.slider.getExtent());
                    int n3;
                    if (SynthSliderUI.access$1700(SynthSliderUI.this)) {
                        n2 = access$1600;
                        n3 = y + n;
                    }
                    else {
                        n3 = access$1600;
                    }
                    int min = Math.min(Math.max(a, n3 - n), n2 - n);
                    SynthSliderUI.this.setThumbLocation(SynthSliderUI.this.thumbRect.x, min);
                    SynthSliderUI.this.slider.setValue(SynthSliderUI.this.valueForYPosition(min + n));
                    break;
                }
                case 0: {
                    int n4 = SynthSliderUI.this.thumbRect.width / 2;
                    int a2 = mouseEvent.getX() - this.offset;
                    int n5 = SynthSliderUI.this.trackRect.x + n4 + SynthSliderUI.this.trackBorder;
                    int n6 = SynthSliderUI.this.trackRect.x + SynthSliderUI.this.trackRect.width - n4 - SynthSliderUI.this.trackBorder;
                    int xPositionForValue = SynthSliderUI.this.xPositionForValue(SynthSliderUI.this.slider.getMaximum() - SynthSliderUI.this.slider.getExtent());
                    if (SynthSliderUI.access$2600(SynthSliderUI.this)) {
                        n5 = xPositionForValue;
                    }
                    else {
                        n6 = xPositionForValue;
                    }
                    int min2 = Math.min(Math.max(a2, n5 - n4), n6 - n4);
                    SynthSliderUI.this.setThumbLocation(min2, SynthSliderUI.this.thumbRect.y);
                    SynthSliderUI.this.slider.setValue(SynthSliderUI.this.valueForXPosition(min2 + n4));
                    break;
                }
                default: {
                    return;
                }
            }
            if (SynthSliderUI.this.slider.getValueIsAdjusting()) {
                SynthSliderUI.access$100(SynthSliderUI.this, true);
            }
            return;
        }
        
        @Override
        public void mouseMoved(MouseEvent mouseEvent) {
            SynthSliderUI.access$3000(SynthSliderUI.this, mouseEvent.getX(), mouseEvent.getY());
        }
    }
}
